﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Management;
using System.Windows.Forms;
using System.Drawing;

namespace TweakAPI.Info
{
    /// <summary>
    /// Provides information about the connected displays.
    /// </summary>
    public struct Display
    {
        /// <summary>
        /// Returns a <see cref="Display"/>-Array containing information about the connected displays.
        /// </summary>
        /// <returns></returns>
        public static Display[] EnumerateScreens()
        {
            List<Display> dsps = new List<Display>();
            foreach(Screen s in Screen.AllScreens)
            {
                Display dsp = new Display();
                dsp.Name = s.DeviceName;
                dsp.Resolution = Resolution.FromRectangle(s.Bounds, s.BitsPerPixel);
                dsp.WorkingArea = s.WorkingArea;
                dsp.IsPrimaryDisplay = s.Primary;
                dsps.Add(dsp);
            }
            return dsps.ToArray();
        }

        /// <summary>
        /// The name.
        /// </summary>
        public string Name { get; set; }
        /// <summary>
        /// The resolution.
        /// </summary>
        public Resolution Resolution { get; set; }
        /// <summary>
        /// The working area.
        /// </summary>
        public Rectangle WorkingArea { get; set; }
        /// <summary>
        /// Information, whether it is the primary display.
        /// </summary>
        public bool IsPrimaryDisplay { get; set; }
    }
}
